@@ -862,7 +862,7 @@ class Data(object):
         :param filepath:
         :return: sdata.Data
         """
-        data = cls()
+        data = cls(name="N.N.")
         if s is None and filepath is not None:
             with open(filepath, "r") as fh:
                 d = json.load(fh)
@@ -877,7 +877,7 @@ class Data(object):
 
         if d:
             if "metadata" in d.keys():
-                data.metadata = data.metadata.from_dict(d["metadata"])
+                data.metadata.update_from_dict(d["metadata"])
             else:
                 logger.error("Data.from_json: table not available")
 
@@ -1170,56 +1170,6 @@ class Data(object):
                         self.metadata.add(name=name, description=old_colname, unit=unit, dtype="float")
             self.table.rename(columns=mapper, inplace=True)
 
-
-class Schema(Data):
-    """Base sdata object"""
-    ATTR_NAMES = []
-
-    def __init__(self, **kwargs):
-        """create Schema object
-
-        .. code-block:: python
-
-            df = pd.DataFrame([1,2,3])
-            data = sdata.Schema(name='my schema',
-                        uuid='38b26864e7794f5182d38259bab85842',
-                        table=df,
-                        description="A remarkable description")
-
-
-        :param name: name of the data object
-        :param table: pandas.DataFrame to store
-        :param uuid: uuid of the object
-        :param metadata: sdata.MetadataSchema object
-        :param description: a string to describe the object
-        """
-
-        # self._uuid = None
-        # self._name = None
-        self._prefix = None
-        # ToDo: add getter and setter for metadata
-        self.metadata = kwargs.get("metadata") or MetadataSchema()
-        _uuid = kwargs.get("uuid") or ""
-        _name = kwargs.get("name") or "N.N."
-        self.metadata.add("name", _name)
-        self.metadata.add("uuid", _uuid)
-
-        self.uuid = kwargs.get("uuid") or uuid.uuid4()
-        self.name = kwargs.get("name") or "N.N."
-        self.prefix = kwargs.get("prefix") or ""
-        self._gen_default_attributes(kwargs.get("default_attributes") or self.ATTR_NAMES)
-        self._group = OrderedDict()
-        self._table = None  # pd.DataFrame()
-        self.table = kwargs.get("table", None)
-        self._description = ""
-        self.description = kwargs.get("description", "")
-
-    def __str__(self):
-        return "(Schema '%s':%s)" % (self.name, self.uuid)
-
-    __repr__ = __str__
-
-
 SDATACLS = {"Data": Data,
             }
 #
